/*  $Id: CacheStrategy.java 1035 2010-06-15 13:08:33Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2010 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;

/**
 * Chache management strategy.
 * Defines the policy to use to choose the element to remove from the cache
 * when cache is full and a new element enters the cache.
 * To be able to make its choice, le strategy must be aware of all insertion, deletion 
 * of object in the cache. It must also be notified for each access in the cache.
 * removed(), used() and added() are the callback to be defined for this purpose.
 * @version $Id: CacheStrategy.java 1035 2010-06-15 13:08:33Z sdevaux $
 * @author Sebastien Devaux
 */
public interface CacheStrategy<K> {
	/**
	 * Selection key to be remove from host cache.
	 * @return key selected, null when cache is empty.
	 */ 
	K select();
	/**
	 * tell strategy a key has been removed.
	 * @param key used key
	 */ 
	void removed(K key);
	/**
	 * tell strategy a key has been used.
	 * @param key used key
	 */ 
	void used(K key);
	/**
	 * telle strategy a key has been added.
	 * In most cases, strategy implementation of added(key) is
	 * the same than uses(key).
	 */ 
	void added(K key);
}
