/*  $Id: FileUtils.java 1035 2010-06-15 13:08:33Z sdevaux $
 *
 * Tabs = 4 chars
 * copyright (C) 2002 Sebastien Devaux
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 *
 *              Sebastien Devaux <sebastien.devaux@laposte.net>
 */
package net.eduvax.util;

import java.io.File;
import java.io.IOException;

/**
 * File utility collection.
 * @version $Id: FileUtils.java 1035 2010-06-15 13:08:33Z sdevaux $
 * @author Sebastien Devaux
 */
public class FileUtils {
	/**
	 * get path to file relative to another file
	 * @param ref reference file path
	 * @param file file path to translate
	 * @return translater file path, 'file' (2nd arg) itself if error
	 * or not compatible.
	 */
	public static File getRelativePath(File ref,File file) {
		File refDir;
		if (ref.isDirectory()) {
			refDir=ref;
		}
		else {
			refDir=ref.getParentFile();
		}
		if (refDir==null) {
			return file;
		}
		String[] refElems;
		String[] fileElems;
		try {
			refElems=refDir.getCanonicalPath().split("\\"+File.separatorChar);
			fileElems=file.getCanonicalPath().split("\\"+File.separatorChar);
		}
		catch (IOException ex) {
			return file;
		}	
		int i=0;
		while (i<fileElems.length && i<refElems.length &&
						refElems[i].equals(fileElems[i])) {
			i++;
		}
		StringBuffer res=new StringBuffer();
		for (int j=i;j<refElems.length;j++) {
			res.append("..");
			res.append(File.separatorChar);
		}	
		for (int j=i;j<fileElems.length;j++) {
			res.append(File.separatorChar);
			res.append(fileElems[j]);
		}
		return new File(res.toString());
	}
}
// vim:tabstop=4:
